@@ -31,17 +31,23 @@ public:
 	}
 	std::string title() override;
 
+protected:
+	std::string main_widget() const override
+	{
+		return "filename";
+	}
+
 private:
 	bool process_operation(Operation op,
 		bool automatic = false,
 		std::vector<std::string>* args = nullptr) override;
 	void update_title(const std::string& working_directory);
 
-	void add_file(ListFormatter& listfmt,
-		std::vector<file_system::FileSystemEntry>& id_at_position,
+	void add_file(std::vector<file_system::FileSystemEntry>& id_at_position,
 		std::string filename);
 	std::string get_filename_suggestion(const std::string& s);
 	std::vector<file_system::FileSystemEntry> id_at_position;
+	std::vector<std::string> lines;
 
 	std::string get_formatted_filename(std::string filename, mode_t mode);
 
