@@ -76,7 +76,7 @@ public:
 		const std::string& searchphrase = "");
 	void push_empty_formaction();
 	void push_help();
-	void push_urlview(const std::vector<LinkPair>& links,
+	void push_urlview(const Links& links,
 		std::shared_ptr<RssFeed>& feed);
 	void push_searchresult(std::shared_ptr<RssFeed> feed,
 		const std::string& phrase = "");
@@ -148,7 +148,6 @@ protected:
 	void handle_cmdline_completion(std::shared_ptr<FormAction> fa);
 	void clear_line(std::shared_ptr<FormAction> fa);
 	void clear_eol(std::shared_ptr<FormAction> fa);
-	void cancel_input(std::shared_ptr<FormAction> fa);
 	void delete_word(std::shared_ptr<FormAction> fa);
 	bool handle_qna_event(const std::string& event, std::shared_ptr<FormAction> fa);
 	void handle_resize();
