@@ -173,7 +173,7 @@ static int rssitem_callback(void* myfeed, int argc, char** argv,
 {
 	std::shared_ptr<RssFeed>* feed =
 		static_cast<std::shared_ptr<RssFeed>*>(myfeed);
-	assert(argc == 13);
+	assert(argc == 15);
 	std::shared_ptr<RssItem> item(new RssItem(nullptr));
 	item->set_guid(argv[0]);
 	item->set_title(argv[1]);
@@ -192,9 +192,11 @@ static int rssitem_callback(void* myfeed, int argc, char** argv,
 
 	item->set_enclosure_url(argv[8] ? argv[8] : "");
 	item->set_enclosure_type(argv[9] ? argv[9] : "");
-	item->set_enqueued((std::string("1") == (argv[10] ? argv[10] : "")));
-	item->set_flags(argv[11] ? argv[11] : "");
-	item->set_base(argv[12] ? argv[12] : "");
+	item->set_enclosure_description(argv[10] ? argv[10] : "");
+	item->set_enclosure_description_mime_type(argv[11] ? argv[11] : "");
+	item->set_enqueued((std::string("1") == (argv[12] ? argv[12] : "")));
+	item->set_flags(argv[13] ? argv[13] : "");
+	item->set_base(argv[14] ? argv[14] : "");
 
 	//(*feed)->items().push_back(item);
 	(*feed)->add_item(item);
@@ -223,7 +225,7 @@ static int search_item_callback(void* myfeed,
 {
 	std::vector<std::shared_ptr<RssItem>>* items =
 			static_cast<std::vector<std::shared_ptr<RssItem>>*>(myfeed);
-	assert(argc == 13);
+	assert(argc == 15);
 	std::shared_ptr<RssItem> item(new RssItem(nullptr));
 	item->set_guid(argv[0]);
 	item->set_title(argv[1]);
@@ -241,9 +243,11 @@ static int search_item_callback(void* myfeed,
 
 	item->set_enclosure_url(argv[8] ? argv[8] : "");
 	item->set_enclosure_type(argv[9] ? argv[9] : "");
-	item->set_enqueued((std::string("1") == argv[10]));
-	item->set_flags(argv[11] ? argv[11] : "");
-	item->set_base(argv[12] ? argv[12] : "");
+	item->set_enclosure_description(argv[10] ? argv[10] : "");
+	item->set_enclosure_description_mime_type(argv[11] ? argv[11] : "");
+	item->set_enqueued((std::string("1") == argv[12]));
+	item->set_flags(argv[13] ? argv[13] : "");
+	item->set_base(argv[14] ? argv[14] : "");
 
 	items->push_back(item);
 	return 0;
@@ -299,7 +303,7 @@ void Cache::set_pragmas()
 static const schema_patches schemaPatches{
 	{	{2, 10},
 		{
-			"CREATE TABLE rss_feed ( "
+			"CREATE TABLE rss_feed ( " // NOLINT(bugprone-suspicious-missing-comma)
 			" rssurl VARCHAR(1024) PRIMARY KEY NOT NULL, "
 			" url VARCHAR(1024) NOT NULL, "
 			" title VARCHAR(1024) NOT NULL ); ",
@@ -388,7 +392,14 @@ static const schema_patches schemaPatches{
 
 			"ALTER TABLE rss_item ADD COLUMN content_mime_type VARCHAR(255) NOT NULL DEFAULT \"\";"
 		}
-	}
+	},
+	{	{2, 33},
+		{
+			"UPDATE metadata SET db_schema_version_major = 2, db_schema_version_minor = 33;",
+			"ALTER TABLE rss_item ADD COLUMN enclosure_description VARCHAR(1024) NOT NULL DEFAULT \"\";",
+			"ALTER TABLE rss_item ADD COLUMN enclosure_description_mime_type VARCHAR(128) NOT NULL DEFAULT \"\";",
+		}
+	},
 
 	// Note: schema changes should use the version number of the release that introduced them.
 };
@@ -596,7 +607,8 @@ std::shared_ptr<RssFeed> Cache::internalize_rssfeed(std::string rssurl,
 	query = prepare_query(
 			"SELECT guid, title, author, url, pubDate, length(content), "
 			"unread, "
-			"feedurl, enclosure_url, enclosure_type, enqueued, flags, base "
+			"feedurl, enclosure_url, enclosure_type, enclosure_description, enclosure_description_mime_type, "
+			"enqueued, flags, base "
 			"FROM rss_item "
 			"WHERE feedurl = '%q' "
 			"AND deleted = 0 "
@@ -670,6 +682,7 @@ std::vector<std::shared_ptr<RssItem>> Cache::search_for_items(
 				"SELECT guid, title, author, url, pubDate, "
 				"length(content), "
 				"unread, feedurl, enclosure_url, enclosure_type, "
+				"enclosure_description, enclosure_description_mime_type, "
 				"enqueued, flags, base "
 				"FROM rss_item "
 				"WHERE (title LIKE '%%%q%%' OR content LIKE '%%%q%%') "
@@ -684,6 +697,7 @@ std::vector<std::shared_ptr<RssItem>> Cache::search_for_items(
 				"SELECT guid, title, author, url, pubDate, "
 				"length(content), "
 				"unread, feedurl, enclosure_url, enclosure_type, "
+				"enclosure_description, enclosure_description_mime_type, "
 				"enqueued, flags, base "
 				"FROM rss_item "
 				"WHERE (title LIKE '%%%q%%' OR content LIKE '%%%q%%') "
@@ -757,13 +771,13 @@ void Cache::do_vacuum()
 	run_sql("VACUUM;");
 }
 
-std::uint64_t Cache::cleanup_cache(std::vector<std::shared_ptr<RssFeed>> feeds,
+std::vector<std::string> Cache::cleanup_cache(std::vector<std::shared_ptr<RssFeed>> feeds,
 	bool always_clean)
 {
 	// we don't use the std::lock_guard<> here... see comments below
 	mtx.lock();
 
-	std::uint64_t unreachable = 0u;
+	std::vector<std::string> unreachable_feeds{};
 	std::string list = "(";
 
 	for (const auto& feed : feeds) {
@@ -812,7 +826,7 @@ std::uint64_t Cache::cleanup_cache(std::vector<std::shared_ptr<RssFeed>> feeds,
 			"Cache::cleanup_cache: NOT cleaning up cache...");
 
 		std::string query = (
-				"SELECT count(rss) "
+				"SELECT DISTINCT rss "
 				"FROM ("
 				"SELECT feedurl AS rss FROM rss_item "
 				"UNION ALL "
@@ -823,15 +837,13 @@ std::uint64_t Cache::cleanup_cache(std::vector<std::shared_ptr<RssFeed>> feeds,
 		query.append(list);
 		query.push_back(';');
 
-		CbHandler count_cbh;
-		run_sql(query, count_callback, &count_cbh);
-		unreachable = count_cbh.count();
+		run_sql(query, vectorofstring_callback, &unreachable_feeds);
 	}
 
 	// WARNING: THE MISSING UNLOCK OPERATION IS MISSING FOR A
 	// PURPOSE! It's missing so that no database operation can occur
 	// after the cache cleanup! mtx->unlock();
-	return unreachable;
+	return unreachable_feeds;
 }
 
 void Cache::update_rssitem_unlocked(std::shared_ptr<RssItem> item,
@@ -873,7 +885,8 @@ void Cache::update_rssitem_unlocked(std::shared_ptr<RssItem> item,
 					"SET title = '%q', author = '%q', url = '%q', "
 					"feedurl = '%q', "
 					"content = '%q', content_mime_type = '%q', enclosure_url = '%q', "
-					"enclosure_type = '%q', base = '%q', unread = "
+					"enclosure_type = '%q', enclosure_description = '%q', "
+					"enclosure_description_mime_type = '%q', base = '%q', unread = "
 					"'%d' "
 					"WHERE guid = '%q'",
 					item->title(),
@@ -884,6 +897,8 @@ void Cache::update_rssitem_unlocked(std::shared_ptr<RssItem> item,
 					description.mime,
 					item->enclosure_url(),
 					item->enclosure_type(),
+					item->enclosure_description(),
+					item->enclosure_description_mime_type(),
 					item->get_base(),
 					(item->unread() ? 1 : 0),
 					item->guid());
@@ -893,7 +908,8 @@ void Cache::update_rssitem_unlocked(std::shared_ptr<RssItem> item,
 					"SET title = '%q', author = '%q', url = '%q', "
 					"feedurl = '%q', "
 					"content = '%q', content_mime_type = '%q', enclosure_url = '%q', "
-					"enclosure_type = '%q', base = '%q' "
+					"enclosure_type = '%q', enclosure_description = '%q', "
+					"enclosure_description_mime_type = '%q', base = '%q' "
 					"WHERE guid = '%q'",
 					item->title(),
 					item->author(),
@@ -903,6 +919,8 @@ void Cache::update_rssitem_unlocked(std::shared_ptr<RssItem> item,
 					description.mime,
 					item->enclosure_url(),
 					item->enclosure_type(),
+					item->enclosure_description(),
+					item->enclosure_description_mime_type(),
 					item->get_base(),
 					item->guid());
 		}
@@ -912,11 +930,10 @@ void Cache::update_rssitem_unlocked(std::shared_ptr<RssItem> item,
 				"INSERT INTO rss_item (guid, title, author, url, "
 				"feedurl, "
 				"pubDate, content, content_mime_type, unread, enclosure_url, "
-				"enclosure_type, enqueued, base) "
+				"enclosure_type, enclosure_description, enclosure_description_mime_type, "
+				"enqueued, base) "
 				"VALUES "
-				"('%q','%q','%q','%q','%q','%u','%q','%q','%d','%q','%q',%d,"
-				" "
-				"'%q')",
+				"('%q','%q','%q','%q','%q','%u','%q','%q','%d','%q','%q','%q','%q',%d, '%q')",
 				item->guid(),
 				item->title(),
 				item->author(),
@@ -928,6 +945,8 @@ void Cache::update_rssitem_unlocked(std::shared_ptr<RssItem> item,
 				(item->unread() ? 1 : 0),
 				item->enclosure_url(),
 				item->enclosure_type(),
+				item->enclosure_description(),
+				item->enclosure_description_mime_type(),
 				item->enqueued() ? 1 : 0,
 				item->get_base());
 		run_sql(insert);
