@@ -2,6 +2,7 @@
 
 #include <algorithm>
 #include <cassert>
+#include <cstdint>
 #include <cstring>
 #include <langinfo.h>
 #include <numeric>
@@ -30,7 +31,7 @@ FeedListFormAction::FeedListFormAction(View* vv,
 	FilterContainer& f,
 	ConfigContainer* cfg,
 	RegexManager& r)
-	: ListFormAction(vv, formstr, "feeds", cfg)
+	: ListFormAction(vv, "feedlist", formstr, "feeds", cfg, r)
 	, zero_feedpos(false)
 	, filter_active(false)
 	, filterpos(0)
@@ -131,9 +132,9 @@ REDO:
 		v->get_ctrl()->reload_urls_file();
 		break;
 	case OP_SORT: {
-		/// This string is related to the letters in parentheses in the
-		/// "Sort by (f)irsttag/..." and "Reverse Sort by
-		/// (f)irsttag/..." messages
+		// i18n: This string is related to the letters in parentheses in the
+		// "Sort by (f)irsttag/..." and "Reverse Sort by
+		// (f)irsttag/..." messages
 		std::string input_options = _("ftauln");
 		char c = v->confirm(
 				_("Sort by "
@@ -622,14 +623,16 @@ void FeedListFormAction::set_feedlist(
 
 	update_visible_feeds(feeds);
 
-	for (const auto& feed : visible_feeds) {
-		listfmt.add_line(format_line(feedlist_format,
-				feed.first,
-				feed.second,
-				width));
-	}
-
-	list.stfl_replace_lines(listfmt);
+	auto render_line = [this, feedlist_format](std::uint32_t line,
+	std::uint32_t width) -> std::string {
+		if (line >= visible_feeds.size())
+		{
+			return "ERROR";
+		}
+		auto& feed = visible_feeds[line];
+		return format_line(feedlist_format, feed.first, feed.second, width);
+	};
+	list.invalidate_list_content(visible_feeds.size(), render_line);
 
 	update_form_title(width);
 }
@@ -696,14 +699,14 @@ void FeedListFormAction::goto_feed(const std::string& str)
 		curpos,
 		str);
 	for (unsigned int i = curpos + 1; i < visible_feeds.size(); ++i) {
-		if (strcasestr(visible_feeds[i].first->title().c_str(),
+		if (strcasestr(get_title(visible_feeds[i].first).c_str(),
 				str.c_str()) != nullptr) {
 			list.set_position(i);
 			return;
 		}
 	}
 	for (unsigned int i = 0; i <= curpos; ++i) {
-		if (strcasestr(visible_feeds[i].first->title().c_str(),
+		if (strcasestr(get_title(visible_feeds[i].first).c_str(),
 				str.c_str()) != nullptr) {
 			list.set_position(i);
 			return;
@@ -932,7 +935,7 @@ void FeedListFormAction::register_format_styles()
 			"style_focus[listfocus]:fg=yellow,bg=blue,attr=bold "
 			"pos[feeds_pos]:0 offset[feeds_offset]:0 %s richtext:1}",
 			attrstr);
-	list.stfl_replace_list(0, textview);
+	list.stfl_replace_list(textview);
 }
 
 void FeedListFormAction::update_form_title(unsigned int width)
