@@ -63,35 +63,13 @@ HtmlRenderer::HtmlRenderer(bool raw)
 
 void HtmlRenderer::render(const std::string& source,
 	std::vector<std::pair<LineType, std::string>>& lines,
-	std::vector<LinkPair>& links,
+	Links& links,
 	const std::string& url)
 {
 	std::istringstream input(source);
 	render(input, lines, links, url);
 }
 
-unsigned int HtmlRenderer::add_link(std::vector<LinkPair>& links,
-	const std::string& link,
-	LinkType type)
-{
-	bool found = false;
-	unsigned int i = 1;
-	for (const auto& l : links) {
-		if (l.first == link) {
-			found = true;
-			break;
-		}
-		i++;
-	}
-	if (!found) {
-		links.push_back(LinkPair(link, type));
-	} else if (links[i - 1].second == LinkType::HREF) {
-		links[i - 1].second = type;
-	}
-
-	return i;
-}
-
 HtmlTag HtmlRenderer::extract_tag(TagSoupPullParser& parser)
 {
 	std::string tagname = parser.get_text();
@@ -104,7 +82,7 @@ HtmlTag HtmlRenderer::extract_tag(TagSoupPullParser& parser)
 
 void HtmlRenderer::render(std::istream& input,
 	std::vector<std::pair<LineType, std::string>>& lines,
-	std::vector<LinkPair>& links,
+	Links& links,
 	const std::string& url)
 {
 	unsigned int image_count = 0;
@@ -176,10 +154,9 @@ void HtmlRenderer::render(std::istream& input,
 					LOG(Level::WARN, "HtmlRenderer::render: found a tag with no href attribute");
 				}
 				if (link.length() > 0) {
-					link_num = add_link(links,
-							utils::censor_url(
-								utils::absolute_url(
-									url, link)),
+					link_num = links.add_link(
+							utils::absolute_url(
+								url, link),
 							LinkType::HREF);
 					if (!raw_) {
 						curline.append("<u>");
@@ -220,11 +197,10 @@ void HtmlRenderer::render(std::istream& input,
 						LOG(Level::WARN, "HtmlRenderer::render: found embed object without src attribute");
 					}
 					if (link.length() > 0) {
-						link_num = add_link(links,
-								utils::censor_url(
-									utils::absolute_url(
-										url,
-										link)),
+						link_num = links.add_link(
+								utils::absolute_url(
+									url,
+									link),
 								LinkType::EMBED);
 						curline.append(strprintf::fmt(
 								"[%s %u]",
@@ -1036,23 +1012,10 @@ void HtmlRenderer::render(std::istream& input,
 			add_line_nonwrappable(s, lines);
 		}
 	}
-
-	// add link list
-	if (links.size() > 0) {
-		add_line("", tables, lines);
-		add_line(_("Links: "), tables, lines);
-		for (unsigned int i = 0; i < links.size(); ++i) {
-			auto link_text = strprintf::fmt("[%u]: %s (%s)",
-					i + 1,
-					links[i].first,
-					type2str(links[i].second));
-			add_line_softwrappable(link_text, lines);
-		}
-	}
 }
 
 void HtmlRenderer::add_media_link(std::string& curline,
-	std::vector<LinkPair>& links, const std::string& url,
+	Links& links, const std::string& url,
 	const std::string& media_url, const std::string& media_title,
 	unsigned int media_count, LinkType type)
 {
@@ -1065,8 +1028,8 @@ void HtmlRenderer::add_media_link(std::string& curline,
 		link_url = utils::censor_url(utils::absolute_url(url, media_url));
 	}
 
-	const std::string type_str = type2str(type);
-	const unsigned int link_num = add_link(links, link_url, type);
+	const std::string type_str = Links::type2str(type);
+	const unsigned int link_num = links.add_link(link_url, type);
 	std::string output;
 
 	if (!media_title.empty()) {
@@ -1088,26 +1051,6 @@ std::string HtmlRenderer::render_hr(const unsigned int width)
 	return result;
 }
 
-std::string HtmlRenderer::type2str(LinkType type)
-{
-	switch (type) {
-	case LinkType::HREF:
-		return _("link");
-	case LinkType::IMG:
-		return _("image");
-	case LinkType::EMBED:
-		return _("embedded flash");
-	case LinkType::IFRAME:
-		return _("iframe");
-	case LinkType::VIDEO:
-		return _("video");
-	case LinkType::AUDIO:
-		return _("audio");
-	default:
-		return _("unknown (bug)");
-	}
-}
-
 void HtmlRenderer::add_nonempty_line(const std::string& curline,
 	std::vector<Table>& tables,
 	std::vector<std::pair<LineType, std::string>>& lines)
