@@ -4,17 +4,20 @@
 #include <cassert>
 #include <cinttypes>
 #include <cstring>
+#include <sstream>
 
 #include "rssfeed.h"
 
 namespace newsboat {
 
-xmlDocPtr opml::generate(const FeedContainer& feedcontainer)
+xmlDocPtr opml::generate(const FeedContainer& feedcontainer, bool version2)
 {
 	xmlDocPtr root = xmlNewDoc((const xmlChar*)"1.0");
 	xmlNodePtr opml_node =
 		xmlNewDocNode(root, nullptr, (const xmlChar*)"opml", nullptr);
-	xmlSetProp(opml_node, (const xmlChar*)"version", (const xmlChar*)"1.0");
+	xmlSetProp(opml_node,
+		(const xmlChar*)"version",
+		(const xmlChar*)(version2 ? "2.0" : "1.0"));
 	xmlDocSetRootElement(root, opml_node);
 
 	xmlNodePtr head = xmlNewTextChild(
@@ -48,6 +51,30 @@ xmlDocPtr opml::generate(const FeedContainer& feedcontainer)
 			xmlSetProp(outline,
 				(const xmlChar*)"title",
 				(const xmlChar*)title.c_str());
+			xmlSetProp(outline,
+				(const xmlChar*)"text",
+				(const xmlChar*)title.c_str());
+
+			if (version2) {
+				// OPML 2.0 supports including tags
+				std::vector<std::string> tags = feed->get_tags();
+				std::string opml_tags;
+
+				bool first_tag = true;
+				for (auto t : tags) {
+					utils::trim(t);
+					t = utils::replace_all(t, ",", "_");
+					if (first_tag) {
+						first_tag = false;
+					} else {
+						opml_tags.append(",");
+					}
+					opml_tags.append(t);
+				}
+				xmlSetProp(outline,
+					(const xmlChar*)"category",
+					(const xmlChar*)opml_tags.c_str());
+			}
 		}
 	}
 
@@ -134,6 +161,24 @@ void rec_find_rss_outlines(
 						"opml::import: url = %s is already in list",
 						quoted_url);
 				}
+
+				// Add tags
+				std::string token;
+				std::istringstream ss;
+				char* category = (char*)xmlGetProp(node, (const xmlChar*)"category");
+				if (category) {
+					ss = std::istringstream(category);
+				}
+
+				auto& urltags = urlcfg.get_tags(quoted_url);
+				while (std::getline(ss, token, ',')) {
+					if (std::find(urltags.begin(), urltags.end(), token) == urltags.end()) {
+						urltags.push_back(token);
+					}
+				}
+
+				xmlFree(category);
+
 			} else {
 				char* text = (char*)xmlGetProp(
 						node, (const xmlChar*)"text");
