@@ -293,8 +293,6 @@ int PbController::run(PbView& v)
 	}));
 	ql->reload(downloads_);
 
-	v.set_keymap(&keys);
-
 	v.run(automatic_dl, cfg.get_configvalue_as_bool("wrap-scroll"));
 
 	Stfl::reset();
@@ -309,6 +307,11 @@ int PbController::run(PbView& v)
 	return EXIT_SUCCESS;
 }
 
+newsboat::KeyMap& PbController::get_keymap()
+{
+	return keys;
+}
+
 void PbController::print_usage(const char* argv0)
 {
 	auto msg = strprintf::fmt(
@@ -427,7 +430,7 @@ void PbController::start_downloads()
 
 void PbController::start_download(Download& item)
 {
-	std::thread t{PodDlThread(&item, &cfg)};
+	std::thread t{PodDlThread(&item, cfg)};
 	t.detach();
 }
 
