@@ -9,10 +9,9 @@
 #include "controller.h"
 #include "curlhandle.h"
 #include "dbexception.h"
-#include "downloadthread.h"
+#include "feedretriever.h"
 #include "fmtstrformatter.h"
 #include "matcherexception.h"
-#include "reloadrangethread.h"
 #include "reloadthread.h"
 #include "rss/exception.h"
 #include "rssfeed.h"
@@ -23,7 +22,7 @@
 
 namespace newsboat {
 
-Reloader::Reloader(Controller* c, Cache* cc, ConfigContainer* cfg)
+Reloader::Reloader(Controller* c, Cache* cc, ConfigContainer& cfg)
 	: ctrl(c)
 	, rsscache(cc)
 	, cfg(cfg)
@@ -39,7 +38,19 @@ void Reloader::spawn_reloadthread()
 void Reloader::start_reload_all_thread(const std::vector<int>& indexes)
 {
 	LOG(Level::INFO, "starting reload all thread");
-	std::thread t(DownloadThread(*this, indexes));
+	std::thread t([=]() {
+		LOG(Level::DEBUG,
+			"Reloader::start_reload_all_thread: inside thread, reloading all "
+			"feeds...");
+		if (trylock_reload_mutex()) {
+			if (indexes.empty()) {
+				reload_all();
+			} else {
+				reload_indexes(indexes);
+			}
+			unlock_reload_mutex();
+		}
+	});
 	t.detach();
 }
 
@@ -79,9 +90,8 @@ void Reloader::reload(unsigned int pos,
 		std::string errmsg;
 		std::shared_ptr<AutoDiscardMessage> message_lifetime;
 		if (!unattended) {
-			const auto max = ctrl->get_feedcontainer()->feeds_size();
 			const std::string progress = show_progress ?
-				strprintf::fmt("(%u/%u) ", pos + 1, max) :
+				strprintf::fmt("(%u/%u) ", ++reload_progress, reload_progress_max) :
 				"";
 			message_lifetime = ctrl->get_view()->get_statusline().show_message_until_finished(
 					strprintf::fmt(_("%sLoading %s..."),
@@ -90,20 +100,23 @@ void Reloader::reload(unsigned int pos,
 		}
 
 		const bool ignore_dl =
-			(cfg->get_configvalue("ignore-mode") == "download");
+			(cfg.get_configvalue("ignore-mode") == "download");
 
-		RssParser parser(oldfeed->rssurl(),
-			rsscache,
-			cfg,
-			ignore_dl ? ctrl->get_ignores() : nullptr,
-			ctrl->get_api());
-		parser.set_easyhandle(&easyhandle);
-		LOG(Level::DEBUG, "Reloader::reload: created parser");
 		try {
 			const auto inner_message_lifetime = message_lifetime;
 			message_lifetime.reset();
 			oldfeed->set_status(DlStatus::DURING_DOWNLOAD);
-			std::shared_ptr<RssFeed> newfeed = parser.parse();
+
+			RssIgnores* ign = ignore_dl ? ctrl->get_ignores() : nullptr;
+
+			LOG(Level::INFO, "Reloader::reload: retrieving feed");
+			FeedRetriever feed_retriever(cfg, *rsscache, ign, ctrl->get_api(), &easyhandle);
+			const rsspp::Feed feed = feed_retriever.retrieve(oldfeed->rssurl());
+
+			LOG(Level::INFO, "Reloader::reload: parsing feed");
+			RssParser parser(oldfeed->rssurl(), *rsscache, cfg, ign);
+
+			std::shared_ptr<RssFeed> newfeed = parser.parse(feed);
 			if (newfeed != nullptr) {
 				ctrl->replace_feed(
 					oldfeed, newfeed, pos, unattended);
@@ -139,6 +152,45 @@ void Reloader::reload(unsigned int pos,
 	}
 }
 
+void Reloader::partition_reload_to_threads(
+	std::function<void(unsigned int start, unsigned int end)> handle_range,
+	unsigned int num_feeds)
+{
+	int num_threads = cfg.get_configvalue_as_int("reload-threads");
+	// TODO: change to std::clamp in C++17
+	const int min_threads = 1;
+	const int max_threads = num_feeds;
+	num_threads = std::max(min_threads, std::min(num_threads, max_threads));
+
+	LOG(Level::DEBUG, "Reloader::partition_reload_to_threads: starting with reload...");
+	reload_progress = 0;
+	reload_progress_max = num_feeds;
+	if (num_threads == 1) {
+		handle_range(0, num_feeds - 1);
+	} else {
+		std::vector<std::pair<unsigned int, unsigned int>> partitions =
+				utils::partition_indexes(0, num_feeds - 1, num_threads);
+		std::vector<std::thread> threads;
+		LOG(Level::DEBUG,
+			"Reloader::partition_reload_to_threads: starting reload threads...");
+		for (int i = 0; i < num_threads - 1; i++) {
+			auto range = partitions[i];
+			threads.emplace_back([=]() {
+				handle_range(range.first, range.second);
+			});
+		}
+		LOG(Level::DEBUG,
+			"Reloader::partition_reload_to_threads: starting my own reload...");
+		handle_range(partitions[num_threads - 1].first,
+			partitions[num_threads - 1].second);
+		LOG(Level::DEBUG,
+			"Reloader::partition_reload_to_threads: joining other threads...");
+		for (size_t i = 0; i < threads.size(); i++) {
+			threads[i].join();
+		}
+	}
+}
+
 void Reloader::reload_all(bool unattended)
 {
 	ScopeMeasure sm("Reloader::reload_all");
@@ -147,42 +199,13 @@ void Reloader::reload_all(bool unattended)
 		ctrl->get_feedcontainer()->unread_feed_count();
 	const auto unread_articles =
 		ctrl->get_feedcontainer()->unread_item_count();
-	int num_threads = cfg->get_configvalue_as_int("reload-threads");
 
 	ctrl->get_feedcontainer()->reset_feeds_status();
 	const auto num_feeds = ctrl->get_feedcontainer()->feeds_size();
 
-	// TODO: change to std::clamp in C++17
-	const int min_threads = 1;
-	const int max_threads = num_feeds;
-	num_threads = std::max(min_threads, std::min(num_threads, max_threads));
-
-	LOG(Level::DEBUG, "Reloader::reload_all: starting with reload all...");
-	if (num_threads == 1) {
-		reload_range(0, num_feeds - 1, unattended);
-	} else {
-		std::vector<std::pair<unsigned int, unsigned int>> partitions =
-				utils::partition_indexes(0, num_feeds - 1, num_threads);
-		std::vector<std::thread> threads;
-		LOG(Level::DEBUG,
-			"Reloader::reload_all: starting reload threads...");
-		for (int i = 0; i < num_threads - 1; i++) {
-			threads.push_back(std::thread(ReloadRangeThread(*this,
-						partitions[i].first,
-						partitions[i].second,
-						unattended)));
-		}
-		LOG(Level::DEBUG,
-			"Reloader::reload_all: starting my own reload...");
-		reload_range(partitions[num_threads - 1].first,
-			partitions[num_threads - 1].second,
-			unattended);
-		LOG(Level::DEBUG,
-			"Reloader::reload_all: joining other threads...");
-		for (size_t i = 0; i < threads.size(); i++) {
-			threads[i].join();
-		}
-	}
+	partition_reload_to_threads([=](unsigned int start, unsigned int end) {
+		reload_range(start, end, unattended);
+	}, num_feeds);
 
 	// refresh query feeds (update and sort)
 	LOG(Level::DEBUG, "Reloader::reload_all: refresh query feeds");
@@ -197,7 +220,7 @@ void Reloader::reload_all(bool unattended)
 		}
 	}
 
-	ctrl->get_feedcontainer()->sort_feeds(cfg->get_feed_sort_strategy());
+	ctrl->get_feedcontainer()->sort_feeds(cfg.get_feed_sort_strategy());
 	ctrl->update_feedlist();
 	ctrl->get_view()->force_redraw();
 
@@ -212,9 +235,11 @@ void Reloader::reload_indexes(const std::vector<int>& indexes, bool unattended)
 	const auto unread_articles =
 		ctrl->get_feedcontainer()->unread_item_count();
 
-	for (const auto& idx : indexes) {
-		reload(idx, true, unattended);
-	}
+	partition_reload_to_threads([&](unsigned int start, unsigned int end) {
+		for (auto i = start; i <= end; ++i) {
+			reload(indexes[i], true, unattended);
+		}
+	}, indexes.size());
 
 	notify_reload_finished(unread_feeds, unread_articles);
 }
@@ -259,22 +284,22 @@ void Reloader::reload_range(unsigned int start,
 
 void Reloader::notify(const std::string& msg)
 {
-	if (cfg->get_configvalue_as_bool("notify-screen")) {
+	if (cfg.get_configvalue_as_bool("notify-screen")) {
 		LOG(Level::DEBUG, "reloader:notify: notifying screen");
 		std::cout << "\033^" << msg << "\033\\";
 		std::cout.flush();
 	}
-	if (cfg->get_configvalue_as_bool("notify-xterm")) {
+	if (cfg.get_configvalue_as_bool("notify-xterm")) {
 		LOG(Level::DEBUG, "reloader:notify: notifying xterm");
 		std::cout << "\033]2;" << msg << "\033\\";
 		std::cout.flush();
 	}
-	if (cfg->get_configvalue_as_bool("notify-beep")) {
+	if (cfg.get_configvalue_as_bool("notify-beep")) {
 		LOG(Level::DEBUG, "reloader:notify: notifying beep");
 		::beep();
 	}
-	if (cfg->get_configvalue("notify-program").length() > 0) {
-		std::string prog = cfg->get_configvalue("notify-program");
+	if (cfg.get_configvalue("notify-program").length() > 0) {
+		std::string prog = cfg.get_configvalue("notify-program");
 		LOG(Level::DEBUG,
 			"reloader:notify: notifying external program `%s'",
 			prog);
@@ -289,7 +314,7 @@ void Reloader::notify_reload_finished(unsigned int unread_feeds_before,
 		ctrl->get_feedcontainer()->unread_feed_count();
 	const auto unread_articles =
 		ctrl->get_feedcontainer()->unread_item_count();
-	const bool notify_always = cfg->get_configvalue_as_bool("notify-always");
+	const bool notify_always = cfg.get_configvalue_as_bool("notify-always");
 
 	if (notify_always || unread_feeds > unread_feeds_before ||
 		unread_articles > unread_articles_before) {
@@ -309,7 +334,7 @@ void Reloader::notify_reload_finished(unsigned int unread_feeds_before,
 			std::to_string(article_count >= 0 ? article_count : 0));
 		fmt.register_fmt(
 			'D', std::to_string(feed_count >= 0 ? feed_count : 0));
-		notify(fmt.do_format(cfg->get_configvalue("notify-format")));
+		notify(fmt.do_format(cfg.get_configvalue("notify-format")));
 	}
 }
 
